@@ -28,9 +28,9 @@ def _validate_confirmation_inputs(user_input: str) -> Union[bool, None]:
         return False
 
     elif user_input == 'q' or user_input == 'quit':
-        console_log('Exit received. Ending execution...', 'error')
+        console_log('Exit received. Ending execution...', 'warning')
         sys.exit()
 
     else:
-        console_log('Invalid input. Enter (q to quit) [y/n]', 'warning')
+        console_log('Invalid input', 'warning')
         return None
